.. faux documentation master file


Welcome to SMock's documentation!
======================================

Overview
--------

The `faux <http://github.com/bprinty/faux>`_ provides utilities for mocking responses from external services during testing. With `faux`, you can easily serve a directory structure mocking url endpoints for an externally managed service and use that server for testing.

For documentation on how to use this package, see the `Usage <./usage.html>`_ section of the documentation.


Content:
--------

.. toctree::
   :maxdepth: 2

   installation
   usage
   api


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
